Switch neutron-tempest-plugin-api job to be ML2/OVN

This patch reverts [1] and switches back to the default networking
backend installed by devstack.

This patch also changes the GRE type networks with VLAN type networks
because of the lack of support.

OVN version is set to v21.03.0. OVN v20.12.0 [2] introduced the support
for ACL log meters (Neutron logging service), but this version is too
old right now.

Partial-Bug: #1928345
Related-Bug: #1929658
Related-Bug: #1914757

[1]https://review.opendev.org/c/openstack/neutron-tempest-plugin/+/791417
[2]https://github.com/ovn-org/ovn/commit/880dca99eaf73db7e783999c29386d03c82093bf

Change-Id: Id087c2a30a7279f9ef9a2c34ddc68a0b11d20c4b
diff --git a/neutron_tempest_plugin/api/test_trunk.py b/neutron_tempest_plugin/api/test_trunk.py
index 1f83bd8..26f8de8 100644
--- a/neutron_tempest_plugin/api/test_trunk.py
+++ b/neutron_tempest_plugin/api/test_trunk.py
@@ -247,21 +247,23 @@
     @classmethod
     def skip_checks(cls):
         super(TrunkTestMtusJSONBase, cls).skip_checks()
-        if not all(cls.is_type_driver_enabled(t) for t in ['gre', 'vxlan']):
-            msg = "Either vxlan or gre type driver not enabled."
+        if not all(cls.is_type_driver_enabled(t) for t in ['vlan', 'vxlan']):
+            msg = "Either vxlan or vlan type driver not enabled."
             raise cls.skipException(msg)
 
     def setUp(self):
         super(TrunkTestMtusJSONBase, self).setUp()
+        physnet_name = CONF.neutron_plugin_options.provider_vlans[0]
 
         # VXLAN autocomputed MTU (1450) is smaller than that of GRE (1458)
         self.smaller_mtu_net = self.create_network(
             name=data_utils.rand_name('vxlan-net'),
             provider_network_type='vxlan')
 
         self.larger_mtu_net = self.create_network(
-            name=data_utils.rand_name('gre-net'),
-            provider_network_type='gre')
+            name=data_utils.rand_name('vlan-net'),
+            provider_network_type='vlan',
+            provider_physical_network=physnet_name)
 
         self.smaller_mtu_port = self.create_port(self.smaller_mtu_net)
         self.smaller_mtu_port_2 = self.create_port(self.smaller_mtu_net)
@@ -247,21 +247,23 @@
 
-        # VXLAN autocomputed MTU (1450) is smaller than that of GRE (1458)
+        # VXLAN autocomputed MTU (1450) is smaller than that of VLAN (1480)
         self.smaller_mtu_net = self.create_network(
             name=data_utils.rand_name('vxlan-net'),